@@ -64,19 +64,7 @@
 
 #include "libgnomeuiP.h"
 
-#include <gtk/gtkversion.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkaccelmap.h>
-
-/* for sound events */
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkcheckmenuitem.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtklinkbutton.h>
+#include <gtk/gtk.h>
 
 /*****************************************************************************
  * libgnomeui
@@ -101,7 +89,7 @@ static void libgnomeui_post_args_parse	(GnomeProgram *app,
 static void libgnomeui_rc_parse		(GnomeProgram *program);
 
 /* Prototype for a private gnome_stock function */
-void _gnome_stock_icons_init (void);
+G_GNUC_INTERNAL void _gnome_stock_icons_init (void);
 
 /* Whether to make noises when the user clicks a button, etc.  We cache it
  * in a boolean rather than querying GConf every time.
